class User < ActiveRecord::Base
  before_save :encrypt_password

  has_many :moves
  has_many :games1, class_name: 'Game', foreign_key: 'player1'
  has_many :games2, class_name: 'Game', foreign_key: 'player2'
  has_many :comments, as: :commentable
  has_many :comments_made, class_name: 'Comment'
  has_and_belongs_to_many :friends,
    class_name: 'User',
    foreign_key: 'user_id',
    association_foreign_key: 'friend_id',
    join_table: 'friends_users'

  attr_accessor :password

  validates :username,
    presence: true,
    length: {in: 4..14, too_long: 'Too long username'},
    uniqueness: true
  validates :password,
    confirmation: true, :if => :password_required?

  def games
    games1 + games2
  end

  def encrypt_password
    return if password.blank?
    if new_record?
      self.salt = Digest::SHA1.hexdigest(Time.now.to_s + email)
    end
    self.encrypted_password = User.encrypt(password, salt)
  end

  def self.encrypt(pass,salt)
    Digest::SHA1.hexdigest(pass+salt)
  end
  
  def authenticated?(pass)
    encrypted_password == User.encrypt(pass, salt)
  end

  def self.authenticate(name,pass)
    user = User.where(username: name).first
    user && user.authenticated?(pass) ? user : nil
  end

  def self.get_users_page(page)
    #User.all
    User.order('username').paginate(:page => page, :per_page=>2)
  end

  def password_required?
    encrypted_password.blank? || !password.blank?
    # self.new_record? || self.password?
  end
end
